@@ -6,6 +6,7 @@
 # This software may be modified and distributed under the terms
 # of the BSD license.  See the LICENSE file for details.
 
+
 def normalize(value):
     """Returns the string with decimal separators normalized."""
-    return value.replace(',', '.')
+    return value.replace(",", ".")
